Skip to contents

Runs urlchecker::url_check() with a database created using the url_db_from_HTML_files function in the tools package.

Usage

html_url_check(
  path = "docs",
  parallel = TRUE,
  pool = curl::new_pool(),
  progress = TRUE,
  fail = FALSE
)

Arguments

path

Path to the directory of HTML files

parallel

If TRUE, check the URLs in parallel

pool

A multi handle created by curl::new_pool(). If NULL use a global pool.

progress

Whether to show the progress bar for parallel checks

fail

If TRUE (the default), throw an error when one or more URLs are flagged, after printing the report. This yields a non-zero exit status, which is useful in CI/CD workflows. Set to FALSE to return the results instead of failing.

Value

A url_checker_db object (invisibly). This is a check_url_db object with an added class with a custom print method.