Skip to contents

Inspect packages using renv::vulns() and pretty-print vulnerable packages using yaml::as.yaml()

Usage

renv_vulns(packages = NULL, quiet = FALSE)

Arguments

packages

A vector of package specifications, of the form <package>==<version> or <package>@<version>.

quiet

disable output and only return the list of vulnerable packages (invisibly).

Value

An R list of vulnerable packages, invisibly.