R/ci.R
renv_vulns.Rd
Inspect packages using renv::vulns() and pretty-print vulnerable packages using yaml::as.yaml()
renv::vulns()
yaml::as.yaml()
renv_vulns(packages = NULL, quiet = FALSE)
A vector of package specifications, of the form <package>==<version> or <package>@<version>.
<package>==<version>
<package>@<version>
disable output and only return the list of vulnerable packages (invisibly).
An R list of vulnerable packages, invisibly.