These functions are re-exported from the urlchecker package.
Usage
url_check(
path = ".",
db = NULL,
parallel = TRUE,
pool = curl::new_pool(),
progress = TRUE,
fail = TRUE
)
url_update(path = ".", results = url_check(path, fail = FALSE))Arguments
- path
Path(s) to check. Each element may be:
A package's (development) source directory tree, a directory holding an unpacked source package, or a source package tarball (
.tar.gz). A tarball is unpacked into a temporary directory (kept for the rest of the session, so the printed report can point into the sources).A directory that is not an R package. All supported files found within (recursively) are scanned for URLs. Supported files are HTML, PDF, Rd, Markdown (
.md,.markdown), R Markdown (.Rmd), Quarto (.qmd) and BibTeX (.bib).A single file of one of the supported types above.
pathmay be a character vector mixing any of these.- db
A url database
- parallel
If
TRUE, check the URLs in parallel- pool
A multi handle created by
curl::new_pool(). IfNULLuse a global pool.- progress
Whether to show the progress bar for parallel checks
- fail
If
TRUE(the default), throw an error when one or more URLs are flagged, after printing the report. This yields a non-zero exit status, which is useful in CI/CD workflows. Set toFALSEto return the results instead of failing.- results
results from url_check.